@@ -2,7 +2,7 @@
  *   KShisen - A japanese game similar to mahjongg                         *
  *   Copyright 1997  Mario Weilguni <mweilguni@sime.com>                   *
  *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
- *   Copyright 2009,2010  Frederik Schwarzer <schwarzer@kde.org>           *
+ *   Copyright 2009-2016  Frederik Schwarzer <schwarzer@kde.org>           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -18,6 +18,9 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
+// STL
+#include <memory>
+
 // Qt
 #include <QApplication>
 #include <QCommandLineParser>
@@ -33,8 +36,12 @@
 #include "app.h"
 #include "debug.h"
 
-Q_LOGGING_CATEGORY(KSHISEN_LOG, "log_kshisen")
-static const char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
+namespace KShisen
+{
+Q_LOGGING_CATEGORY(KSHISEN_General, "kshisen")
+} // namespace KShisen
+
+static constexpr char description[] = I18N_NOOP("A KDE game similar to Mahjongg");
 
 int main(int argc, char ** argv)
 {
@@ -48,8 +55,8 @@ int main(int argc, char ** argv)
 
     KLocalizedString::setApplicationDomain("kshisen");
 
-    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"), QStringLiteral("1.10.1"),
-                         i18n(description), KAboutLicense::GPL, i18n("(c) 1997, Mario Weilguni"));
+    KAboutData aboutData(QStringLiteral("kshisen"), i18n("Shisen-Sho"), QStringLiteral("1.10+ #25"),
+                         i18n(description), KAboutLicense::GPL, i18n("Copyright 1997 Mario Weilguni"));
     aboutData.setHomepage(QStringLiteral("http://games.kde.org/kshisen"));
     aboutData.addAuthor(i18n("Frederik Schwarzer"), i18n("Current Maintainer"), QStringLiteral("schwarzer@kde.org"));
     aboutData.addAuthor(i18n("Dave Corrie"), i18n("Former Maintainer"), QStringLiteral("kde@davecorrie.com"));
@@ -71,7 +78,7 @@ int main(int argc, char ** argv)
 
     KDBusService service;
 
-    auto app = new App();
+    auto app = new KShisen::App();
     app->show();
     return a.exec();
 }
